Objects can be created by calls of the form new("AffyProbesMatch", ...). An object will store the result of
matching probe sequences against target sequences.
Slots
pm:
Object of class "list":
each element is vector of index values
mm:
Object of class "list":
each element is vector of index values
labels:
Object of class "character"
chip_type:
Object of class "character"
and of length 1.
probes:
Object of class "ANY":
the probetable object used to perform the matches.
Methods
combine
signature(x = "AffyProbesMatch", y =
"AffyProbesMatch"): combine two instances. This is can
be useful when splitting the list of target sequences to
parallelized the job.
show
signature(x = "AffyProbesMatch"):Show the
instance.
toHypergraph
signature(object = "AffyProbesMatch"):
build an Hypergraph from the matches.