Learn R Programming

altcdfenvs (version 2.34.0)

buildCdfEnv.biostrings: Build CDF environments

Description

Build CDF environment from Biostrings matchPDict results

Usage

buildCdfEnv.biostrings(apm, abatch = NULL, nrow.chip = NULL, ncol.chip = NULL, simplify = TRUE, x.colname = "x", y.colname = "y", verbose = FALSE)

Arguments

apm
AffyProbesMatch
abatch
AffyBatch
nrow.chip
number of rows for the chip type (see details)
ncol.chip
number of columns for the chip type (see details)
simplify
simplify the environment built (removing target names when there is no matching probe)
x.colname
column name
y.colname
column name
verbose
verbose TRUE/FALSE

Value

An instance of class CdfEnvAffy.

Details

Whenever an abatch is specified, nrow.chip and ncol.chip are not needed. Specifying the an AffyBatch in abatch is the easiest way to specify information about the geometry of a chip type.