Learn R Programming

altcdfenvs (version 2.34.0)

getxy.probeseq: A function to get the XY coordinates from a probes sequences data frame

Description

A function to get the XY coordinates from a probes sequences data.frame

Usage

getxy.probeseq(ppset.id = NULL, probeseq = NULL, i.row = NULL, xy.offset = NULL, x.colname = "x", y.colname = "y")

Arguments

ppset.id
The probe sets of interest (a vector of mode character.
probeseq
The probe sequence data.frame (see details).
i.row
Row indexes in the data.frame (see details).
xy.offset
Offset for the xy coordinates. if NULL, uses the default offset stored as an option for the affy package.
x.colname, y.colname
The probe sequence packages have seen the names for the columns in their data.frame. This parameters exists to let us follow these changes.

Value

A matrix of two columns. The first column contains x coordinates, while the second column contains y coordinates.

Warning

The parameter xy.offset.one is here for historical reasons. This should not be touched, the option in the affy package should be modified if one wishes to modify this. This function should not be confused with the methods index2xy and similar. Here the the XY coordinate come from a data.frame that stores information about an arbitrary number probes on the chip. (See the `probe sequence' data packages on Bioconductor, and the package Biostrings). The methods index2xy are meant to interact with instances of class AffyBatch.

Details

The data.frame passed as argument probeseq is expected to have (at least) the following columns: Probe.X, Probe.Y and Probe.Set.Name. When the argument ppset.id is not null, the probe sets

Examples

Run this code
##---- Should be DIRECTLY executable !! ----

Run the code above in your browser using DataLab