Learn R Programming

altcdfenvs (version 2.34.0)

indexProbes.CdfEnvAffy: indexes for probes

Description

A function to get the index for probes

Usage

indexProbes.CdfEnvAffy(object, which, probeSetNames = NULL)

Arguments

object
CdfEnvAffy
which
which kind of probe are of interest (see details).
probeSetNames
names of the probe sets of interest. If NULL, all the probe sets are considered.

Value

A list of indexes.

Details

The parameter which let one specify which category of probes are of interest. In the case of Affymetrix chips, probes can be "pm" probes or "mm" probes. It the parameter is set to c("pm", "mm"), both are returned. Should other categories be defined, they can be handled as well.

See Also

CdfEnvAffy-class, AffyBatch-class