unique.CdfEnvAffy: Remove duplicated elements from a CdfEnvAffy
Description
Remove duplicated elements from a CdfEnvAffy
Usage
"unique"(x, incomparables = FALSE, simplify = TRUE, verbose = FALSE, ...)
Arguments
x
An instance of CdfEnvAffy-class
incomparables
(not yet implemented)
simplify
simplify the result
...
(here for compatibility with the generic unique)
Value
An instance of CdfEnvAffy-class in which probes used several
times are removed.
Warning
The function differs slightly from the generic
unique. Here the elements found in several place a merely removed.Details
The parameter simplify has the same function as the one with
the same name in countduplicated.